@@ -10,11 +10,7 @@ has '+ns'   => ( default => 'Pcore::Redis' );
 
 has redis_ver => ( is => 'lazy', isa => Str, init_arg => undef );
 
-our $CFG = {
-    REDIS => {    #
-        REDIS_VER => undef,
-    }
-};
+our $CFG = { redis_ver => undef, };
 
 # CLI
 around CLI => sub ( $orig, $self ) {
@@ -26,7 +22,7 @@ around CLI => sub ( $orig, $self ) {
 };
 
 sub _build_redis_ver ($self) {
-    return $self->cfg->{REDIS}->{REDIS_VER} || $ENV->dist('Pcore-Redis')->cfg->{REDIS}->{REDIS_VER};
+    return $self->cfg->{redis_ver} || $ENV->dist('Pcore-Redis')->cfg->{redis_ver};
 }
 
 # APP
@@ -34,47 +30,43 @@ around _build_cfg => sub ( $orig, $self ) {
     return P->hash->merge(
         $self->$orig,
         $CFG,
-        {   REDIS => {
-                SERVER => {
-                    pidfile                     => $self->app_dir . 'redis.pid',
-                    port                        => 6379,                                            # use 0 to stop TCP interface
-                    tcp_backlog                 => 511,
-                    bind                        => [qw[127.0.0.1]],
-                    unixsocket                  => q[/tmp/] . $self->name . q[.sock],
-                    unixsocketperm              => 755,
-                    timeout                     => 0,
-                    tcp_keepalive               => 0,
-                    loglevel                    => 'notice',
-                    logfile                     => $ENV->{LOG_DIR} . $self->name . q[-redis.log],
-                    databases                   => 16,
-                    save                        => [ [ 900, 1 ], [ 300, 10 ], [ 60, 10_000 ], ],
-                    stop_writes_on_bgsave_error => 'yes',
-                    rdbcompression              => 'yes',
-                    rdbchecksum                 => 'yes',
-                    dbfilename                  => $self->name . '.rdb',
-                    dir                         => $self->alien_data_dir,
-                    slave_serve_stale_data      => 'yes',
-                    slave_read_only             => 'yes',
-                    repl_disable_tcp_nodelay    => 'no',
-                    slave_priority              => 100,
-                    requirepass                 => undef,
-                    appendonly                  => 'yes',
-                    appendfilename              => $self->name . '.aof',
-                },
-            }
+        {   server => {
+                pidfile                     => $self->app_dir . 'redis.pid',
+                port                        => 6379,                                            # use 0 to stop TCP interface
+                tcp_backlog                 => 511,
+                bind                        => [qw[127.0.0.1]],
+                unixsocket                  => q[/tmp/] . $self->name . q[.sock],
+                unixsocketperm              => 755,
+                timeout                     => 0,
+                tcp_keepalive               => 0,
+                loglevel                    => 'notice',
+                logfile                     => $ENV->{LOG_DIR} . $self->name . q[-redis.log],
+                databases                   => 16,
+                save                        => [ [ 900, 1 ], [ 300, 10 ], [ 60, 10_000 ], ],
+                stop_writes_on_bgsave_error => 'yes',
+                rdbcompression              => 'yes',
+                rdbchecksum                 => 'yes',
+                dbfilename                  => $self->name . '.rdb',
+                dir                         => $self->alien_data_dir,
+                slave_serve_stale_data      => 'yes',
+                slave_read_only             => 'yes',
+                repl_disable_tcp_nodelay    => 'no',
+                slave_priority              => 100,
+                requirepass                 => undef,
+                appendonly                  => 'yes',
+                appendfilename              => $self->name . '.aof',
+            },
         }
     );
 };
 
 around _create_local_cfg => sub ( $orig, $self ) {
     my $local_cfg = {
-        REDIS => {
-            REDIS_VER => $self->cfg->{REDIS}->{REDIS_VER},
-            SERVER    => $self->cfg->{REDIS}->{SERVER},
-        },
+        redis_ver => $self->cfg->{redis_ver},
+        server    => $self->cfg->{server},
     };
 
-    $local_cfg->{REDIS}->{SERVER}->{requirepass} = P->random->bytes_hex(32);
+    $local_cfg->{server}->{requirepass} = P->random->bytes_hex(32);
 
     return P->hash->merge( $self->$orig, $local_cfg );
 };
@@ -160,16 +152,16 @@ sub generate_alien_cfg ($self) {
         return;
     };
 
-    for my $key ( sort keys %{ $self->cfg->{REDIS}->{SERVER} } ) {
-        next if !defined $self->cfg->{REDIS}->{SERVER}->{$key};
+    for my $key ( sort keys %{ $self->cfg->{server} } ) {
+        next if !defined $self->cfg->{server}->{$key};
 
-        if ( ref $self->cfg->{REDIS}->{SERVER}->{$key} eq 'ARRAY' ) {
-            for ( @{ $self->cfg->{REDIS}->{SERVER}->{$key} } ) {
+        if ( ref $self->cfg->{server}->{$key} eq 'ARRAY' ) {
+            for ( @{ $self->cfg->{server}->{$key} } ) {
                 $add_key->( $key, $_ );
             }
         }
         else {
-            $add_key->( $key, $self->cfg->{REDIS}->{SERVER}->{$key} );
+            $add_key->( $key, $self->cfg->{server}->{$key} );
         }
     }
 
